==> icingadb-web_1.0.0.orig.tar.gz: icingadb-web-1.0.0/README.md <==
# Icinga DB Web

[![PHP Support](https://img.shields.io/badge/php-%3E%3D%207.2-777BB4?logo=PHP)](https://php.net/)
![Build Status](https://github.com/icinga/icingaweb2-module-icingadb/workflows/PHP%20Tests/badge.svg?branch=master)
[![Github Tag](https://img.shields.io/github/tag/Icinga/icingaweb2-module-icingadb.svg)](https://github.com/Icinga/icingaweb2-module-icingadb)

Icinga DB is a set of components for publishing, synchronizing and
visualizing monitoring data in the Icinga ecosystem, consisting of:

* Icinga DB Web which connects to both a Redis server and a database to view and work with
  most up-to-date monitoring data
* Icinga 2 with its [Icinga DB feature](https://icinga.com/docs/icinga-2/latest/doc/14-features/#icinga-db) enabled,
  responsible for publishing the data to the Redis server, i.e. configuration and its runtime updates, check results, state changes,
  downtimes, acknowledgements, notifications, and other events such as flapping
* And the [Icinga DB daemon](https://icinga.com/docs/icinga-db),
  which synchronizes the data between the Redis server and the database

![Icinga DB Architecture](doc/res/icingadb-architecture.png)

## Documentation

Icinga DB Web documentation is available at [icinga.com/docs](https://icinga.com/docs/icingadb-web/latest/).

## Features

Icinga DB Web offers a modern and streamlined design to provide a clear and
concise view of your monitoring environment, also with dark and light mode support.

![Icinga DB Dashboard](doc/res/icingadb-dashboard.png)

### Various List Layouts

The view switcher allows to control the level of detail displayed in host and service list views:

![View Switcher Preview](doc/res/view-switcher-preview.png)

### Search with Autocomplete

The search bar in list views can be used for everything from simple searches to creating complex filters.
It allows full keyboard control and also supports contextual auto-completion.
In addition, there is an editor for easier filter creation.

![Searchbar Completion Preview](doc/res/searchbar-completion-preview.png)

### Clean Detail Views

Host and service detail views are structured to make best use of available space.
Related information is grouped and important information is at the top for instant access without having to scroll down.

![Service Detail Preview](doc/res/service-detail-preview.png)

### Modal Dialogs

Any interaction that requires user input, such as acknowledging problems, scheduling downtimes, etc.,
shows a modal dialog over the current view to preserve context and focus on interaction.

![Modal Dialog Preview](doc/res/modal-dialog-preview.png)

### Bulk Operations

Bulk interactions such as scheduling downtimes for multiple objects, acknowledging multiple problems, etc.
are easily accomplished with the `Continue With` control that operates on filtered lists.

![Continue With Preview](doc/res/continue-with-preview.png)

## License

Icinga DB Web and the Icinga DB Web documentation are licensed under the terms of the
[GNU General Public License Version 2](LICENSE).

==> icingadb-web_1.0.2.orig.tar.gz: icingadb-web-1.0.2/README.md <==
# Icinga DB Web

[![PHP Support](https://img.shields.io/badge/php-%3E%3D%207.2-777BB4?logo=PHP)](https://php.net/)
![Build Status](https://github.com/icinga/icingaweb2-module-icingadb/workflows/PHP%20Tests/badge.svg?branch=master)
[![Github Tag](https://img.shields.io/github/tag/Icinga/icingaweb2-module-icingadb.svg)](https://github.com/Icinga/icingaweb2-module-icingadb)

Icinga DB is a set of components for publishing, synchronizing and
visualizing monitoring data in the Icinga ecosystem, consisting of:

* Icinga DB Web which connects to both a Redis server and a database to view and work with
  most up-to-date monitoring data
* Icinga 2 with its [Icinga DB feature](https://icinga.com/docs/icinga-2/latest/doc/14-features/#icinga-db) enabled,
  responsible for publishing the data to the Redis server, i.e. configuration and its runtime updates, check results, state changes,
  downtimes, acknowledgements, notifications, and other events such as flapping
* And the [Icinga DB daemon](https://icinga.com/docs/icinga-db),
  which synchronizes the data between the Redis server and the database

![Icinga DB Architecture](doc/res/icingadb-architecture.png)

## Documentation

Icinga DB Web documentation is available at [icinga.com/docs](https://icinga.com/docs/icinga-db-web/latest/).

## Features

Icinga DB Web offers a modern and streamlined design to provide a clear and
concise view of your monitoring environment, also with dark and light mode support.

![Icinga DB Dashboard](doc/res/icingadb-dashboard.png)

### Various List Layouts

The view switcher allows to control the level of detail displayed in host and service list views:

![View Switcher Preview](doc/res/view-switcher-preview.png)

### Search with Autocomplete

The search bar in list views can be used for everything from simple searches to creating complex filters.
It allows full keyboard control and also supports contextual auto-completion.
In addition, there is an editor for easier filter creation.

![Searchbar Completion Preview](doc/res/searchbar-completion-preview.png)

### Clean Detail Views

Host and service detail views are structured to make best use of available space.
Related information is grouped and important information is at the top for instant access without having to scroll down.

![Service Detail Preview](doc/res/service-detail-preview.png)

### Modal Dialogs

Any interaction that requires user input, such as acknowledging problems, scheduling downtimes, etc.,
shows a modal dialog over the current view to preserve context and focus on interaction.

![Modal Dialog Preview](doc/res/modal-dialog-preview.png)

### Bulk Operations

Bulk interactions such as scheduling downtimes for multiple objects, acknowledging multiple problems, etc.
are easily accomplished with the `Continue With` control that operates on filtered lists.

![Continue With Preview](doc/res/continue-with-preview.png)

## License

Icinga DB Web and the Icinga DB Web documentation are licensed under the terms of the
[GNU General Public License Version 2](LICENSE).
